import { NgModule } from '@angular/core';

/*
  Jalaali years starting the 33-year rule.
*/
const breaks = [
    -61, 9, 38, 199, 426, 686, 756, 818, 1111, 1181, 1210,
    1635, 2060, 2097, 2192, 2262, 2324, 2394, 2456, 3178
];
/*
  Converts a Gregorian date to Jalaali.
*/
function toJalaali(gy, gm, gd) {
    if (Object.prototype.toString.call(gy) === '[object Date]') {
        gd = gy.getDate();
        gm = gy.getMonth() + 1;
        gy = gy.getFullYear();
    }
    return d2j(g2d(gy, gm, gd));
}
/*
  Converts a Jalaali date to Gregorian.
*/
function toGregorian(jy, jm, jd) {
    return d2g(j2d(jy, jm, jd));
}
/*
  Checks whether a Jalaali date is valid or not.
*/
function isValidJalaaliDate(jy, jm, jd) {
    return (jy >= -61 &&
        jy <= 3177 &&
        jm >= 1 &&
        jm <= 12 &&
        jd >= 1 &&
        jd <= jalaaliMonthLength(jy, jm));
}
/*
  Is this a leap year or not?
*/
function isLeapJalaaliYear(jy) {
    return jalCalLeap(jy) === 0;
}
/*
  Number of days in a given month in a Jalaali year.
*/
function jalaaliMonthLength(jy, jm) {
    if (jm <= 6) {
        return 31;
    }
    if (jm <= 11) {
        return 30;
    }
    if (isLeapJalaaliYear(jy)) {
        return 30;
    }
    return 29;
}
/*
    This function determines if the Jalaali (Persian) year is
    leap (366-day long) or is the common year (365 days)

    @param jy Jalaali calendar year (-61 to 3177)
    @returns number of years since the last leap year (0 to 4)
 */
function jalCalLeap(jy) {
    let bl = breaks.length, jp = breaks[0], jm, jump, leap, n, i;
    if (jy < jp || jy >= breaks[bl - 1]) {
        throw new Error("Invalid Jalaali year " + jy);
    }
    for (i = 1; i < bl; i += 1) {
        jm = breaks[i];
        jump = jm - jp;
        if (jy < jm) {
            break;
        }
        jp = jm;
    }
    n = jy - jp;
    if (jump - n < 6) {
        n = n - jump + div(jump + 4, 33) * 33;
    }
    leap = mod$1(mod$1(n + 1, 33) - 1, 4);
    if (leap === -1) {
        leap = 4;
    }
    return leap;
}
/*
  This function determines if the Jalaali (Persian) year is
  leap (366-day long) or is the common year (365 days), and
  finds the day in March (Gregorian calendar) of the first
  day of the Jalaali year (jy).

  @param jy Jalaali calendar year (-61 to 3177)
  @param withoutLeap when don't need leap (true or false) default is false
  @return
    leap: number of years since the last leap year (0 to 4)
    gy: Gregorian year of the beginning of Jalaali year
    march: the March day of Farvardin the 1st (1st day of jy)
  @see: http://www.astro.uni.torun.pl/~kb/Papers/EMP/PersianC-EMP.htm
  @see: http://www.fourmilab.ch/documents/calendar/
*/
function jalCal(jy, withoutLeap) {
    let bl = breaks.length, gy = jy + 621, leapJ = -14, jp = breaks[0], jm, jump, leap, leapG, march, n, i;
    if (jy < jp || jy >= breaks[bl - 1]) {
        throw new Error("Invalid Jalaali year " + jy);
    }
    // Find the limiting years for the Jalaali year jy.
    for (i = 1; i < bl; i += 1) {
        jm = breaks[i];
        jump = jm - jp;
        if (jy < jm) {
            break;
        }
        leapJ = leapJ + div(jump, 33) * 8 + div(mod$1(jump, 33), 4);
        jp = jm;
    }
    n = jy - jp;
    // Find the number of leap years from AD 621 to the beginning
    // of the current Jalaali year in the Persian calendar.
    leapJ = leapJ + div(n, 33) * 8 + div(mod$1(n, 33) + 3, 4);
    if (mod$1(jump, 33) === 4 && jump - n === 4) {
        leapJ += 1;
    }
    // And the same in the Gregorian calendar (until the year gy).
    leapG = div(gy, 4) - div((div(gy, 100) + 1) * 3, 4) - 150;
    // Determine the Gregorian date of Farvardin the 1st.
    march = 20 + leapJ - leapG;
    // return with gy and march when we don't need leap
    if (withoutLeap) {
        return { gy: gy, march: march };
    }
    // Find how many years have passed since the last leap year.
    if (jump - n < 6) {
        n = n - jump + div(jump + 4, 33) * 33;
    }
    leap = mod$1(mod$1(n + 1, 33) - 1, 4);
    if (leap === -1) {
        leap = 4;
    }
    return { leap, gy, march };
}
/*
  Converts a date of the Jalaali calendar to the Julian Day number.

  @param jy Jalaali year (1 to 3100)
  @param jm Jalaali month (1 to 12)
  @param jd Jalaali day (1 to 29/31)
  @return Julian Day number
*/
function j2d(jy, jm, jd) {
    let r = jalCal(jy, true);
    return g2d(r.gy, 3, r.march) + (jm - 1) * 31 - div(jm, 7) * (jm - 7) + jd - 1;
}
/*
  Converts the Julian Day number to a date in the Jalaali calendar.

  @param jdn Julian Day number
  @return
    jy: Jalaali year (1 to 3100)
    jm: Jalaali month (1 to 12)
    jd: Jalaali day (1 to 29/31)
*/
function d2j(jdn) {
    let gy = d2g(jdn).gy, // Calculate Gregorian year (gy).
    jy = gy - 621, r = jalCal(jy, false), jdn1f = g2d(gy, 3, r.march), jd, jm, k;
    // Find number of days that passed since 1 Farvardin.
    k = jdn - jdn1f;
    if (k >= 0) {
        if (k <= 185) {
            // The first 6 months.
            jm = 1 + div(k, 31);
            jd = mod$1(k, 31) + 1;
            return { jy, jm, jd };
        }
        else {
            // The remaining months.
            k -= 186;
        }
    }
    else {
        // Previous Jalaali year.
        jy -= 1;
        k += 179;
        if (r.leap === 1) {
            k += 1;
        }
    }
    jm = 7 + div(k, 30);
    jd = mod$1(k, 30) + 1;
    return { jy, jm, jd };
}
/*
  Calculates the Julian Day number from Gregorian or Julian
  calendar dates. This integer number corresponds to the noon of
  the date (i.e. 12 hours of Universal Time).
  The procedure was tested to be good since 1 March, -100100 (of both
  calendars) up to a few million years into the future.

  @param gy Calendar year (years BC numbered 0, -1, -2, ...)
  @param gm Calendar month (1 to 12)
  @param gd Calendar day of the month (1 to 28/29/30/31)
  @return Julian Day number
*/
function g2d(gy, gm, gd) {
    let d = div((gy + div(gm - 8, 6) + 100100) * 1461, 4) +
        div(153 * mod$1(gm + 9, 12) + 2, 5) +
        gd -
        34840408;
    d = d - div(div(gy + 100100 + div(gm - 8, 6), 100) * 3, 4) + 752;
    return d;
}
/*
  Calculates Gregorian and Julian calendar dates from the Julian Day number
  (jdn) for the period since jdn=-34839655 (i.e. the year -100100 of both
  calendars) to some millions years ahead of the present.

  @param jdn Julian Day number
  @return
    gy: Calendar year (years BC numbered 0, -1, -2, ...)
    gm: Calendar month (1 to 12)
    gd: Calendar day of the month M (1 to 28/29/30/31)
*/
function d2g(jdn) {
    let j, i, gd, gm, gy;
    j = 4 * jdn + 139361631;
    j = j + div(div(4 * jdn + 183187720, 146097) * 3, 4) * 4 - 3908;
    i = div(mod$1(j, 1461), 4) * 5 + 308;
    gd = div(mod$1(i, 153), 5) + 1;
    gm = mod$1(div(i, 153), 12) + 1;
    gy = div(j, 1461) - 100100 + div(8 - gm, 6);
    return { gy, gm, gd };
}
/*
  Utility helper functions.
*/
function div(a, b) {
    return ~~(a / b);
}
function mod$1(a, b) {
    return a - ~~(a / b) * b;
}

// retrieved from https://www.fourmilab.ch/documents/calendar/ by John Walker.
/*  MOD  --  Modulus function which works for non-integers.  */
function mod(a, b) {
    return a - (b * Math.floor(a / b));
}
//  LEAP_GREGORIAN  --  Is a given year in the Gregorian calendar a leap year ?
function leap_gregorian(y) {
    return ((y % 4) === 0) && (!(((y % 100) === 0) && ((y % 400) !== 0)));
}
const GREGORIAN_EPOCH = 1721425.5;
function gregorian_to_jd(y, m, d) {
    return (GREGORIAN_EPOCH -
        1 +
        365 * (y - 1) +
        Math.floor((y - 1) / 4) +
        -Math.floor((y - 1) / 100) +
        Math.floor((y - 1) / 400) +
        Math.floor((367 * m - 362) / 12 + (m <= 2 ? 0 : leap_gregorian(y) ? -1 : -2) + d));
}
//  JD_TO_GREGORIAN  --  Calculate Gregorian calendar date from Julian day
function jd_to_gregorian(jd) {
    let wjd, depoch, quadricent, dqc, cent, dcent, quad, dquad, yindex, dyindex, year, yearday, leapadj, month, day;
    wjd = Math.floor(jd - 0.5) + 0.5;
    depoch = wjd - GREGORIAN_EPOCH;
    quadricent = Math.floor(depoch / 146097);
    dqc = mod(depoch, 146097);
    cent = Math.floor(dqc / 36524);
    dcent = mod(dqc, 36524);
    quad = Math.floor(dcent / 1461);
    dquad = mod(dcent, 1461);
    yindex = Math.floor(dquad / 365);
    year = (quadricent * 400) + (cent * 100) + (quad * 4) + yindex;
    if (!((cent === 4) || (yindex === 4))) {
        year++;
    }
    yearday = wjd - gregorian_to_jd(year, 1, 1);
    leapadj = ((wjd < gregorian_to_jd(year, 3, 1)) ? 0 : (leap_gregorian(year) ? 1 : 2));
    month = Math.floor((((yearday + leapadj) * 12) + 373) / 367);
    day = (wjd - gregorian_to_jd(year, month, 1)) + 1;
    return new Array(year, month, day);
}
//  LEAP_ISLAMIC  --  Is a given year a leap year in the Islamic calendar ?
function leap_islamic(year) {
    return (((year * 11) + 14) % 30) < 11;
}
//  ISLAMIC_TO_JD  --  Determine Julian day from Islamic date
const ISLAMIC_EPOCH = 1948439.5;
function islamic_to_jd(y, m, d) {
    return (d + Math.ceil(29.5 * (m - 1)) + (y - 1) * 354 + Math.floor((3 + 11 * y) / 30) + ISLAMIC_EPOCH - 1);
}
//  JD_TO_ISLAMIC  --  Calculate Islamic date from Julian day
function jd_to_islamic(jd) {
    jd = Math.floor(jd) + 0.5;
    const year = Math.floor((30 * (jd - ISLAMIC_EPOCH) + 10646) / 10631);
    const month = Math.min(12, Math.ceil((jd - (29 + islamic_to_jd(year, 1, 1))) / 29.5) + 1);
    const day = jd - islamic_to_jd(year, month, 1) + 1;
    return new Array(year, month, day);
}
function days_in_month(y, m) {
    return [null, 30, 29, 30, 29, 30, 29, 30, 29, 30, 29, 30, leap_islamic(y) ? 30 : 29][m];
}
function greg_to_islamic(d) {
    const is = jd_to_islamic(gregorian_to_jd(d.getFullYear(), d.getMonth() + 1, d.getDate())
        + Math.floor(d.getSeconds() + 60 * (d.getMinutes() + 60 * d.getHours()) + 0.5)
            / 86400.0);
    return { iy: is[0], im: is[1], id: is[2] };
}
function islamic_to_greg(d) {
    const greg = jd_to_gregorian(islamic_to_jd(d.iy, d.im, d.id));
    return { gy: greg[0], gm: greg[1], gd: greg[2] };
}

class Ymd {
}
class Hms {
}
/**
 * Month number should be 1-based (unlike Date class)
 */
class NiDatetime {
    constructor(date) {
        this.use(date);
    }
    use(date) {
        this.__date = date ? new Date(date) : date;
        return this;
    }
    set ymd(ymd) { }
    get ymd() { return this.__ymd(); }
    __ymd() { return { year: this.year, month: this.month, date: this.date }; }
    get hours12() { return this.hours > 12 ? this.hours % 12 : this.hours; }
    get hours() { return this.__date ? this.__date.getHours() : null; }
    set hours(hours) {
        this.__date = new Date(this.__date.getFullYear(), this.__date.getMonth(), this.__date.getDate(), hours, this.__date.getMinutes(), this.__date.getSeconds());
        this.use(this.__date);
    }
    get minutes() { return this.__date ? this.__date.getMinutes() : null; }
    set minutes(minutes) {
        this.__date = new Date(this.__date.getFullYear(), this.__date.getMonth(), this.__date.getDate(), this.__date.getHours(), minutes, this.__date.getSeconds());
        this.use(this.__date);
    }
    get seconds() { return this.__date ? this.__date.getSeconds() : null; }
    set seconds(seconds) {
        this.__date = new Date(this.__date.getFullYear(), this.__date.getMonth(), this.__date.getDate(), this.__date.getHours(), this.__date.getMinutes(), seconds);
        this.use(this.__date);
    }
    get am() { return this.hours < 12; }
    set am(toggle) { this.hours = this.hours12 + (toggle ? 0 : 12); }
    get pm() { return !this.am; }
    set pm(toggle) { this.hours = this.hours12 + (toggle ? 12 : 0); }
}
/**
 * Islamic Implemendation of NiDate
 */
class NiIslamicDatetime extends NiDatetime {
    constructor(date) {
        super(date);
        this.__idate = { iy: null, im: null, id: null };
        this.use(date);
    }
    use(date) {
        this.__idate = date ? greg_to_islamic(date) : { iy: null, im: null, id: null };
        return super.use(date);
    }
    get year() { return this.__idate.iy; }
    get month() { return this.__idate.im; }
    get date() { return this.__idate.id; }
    get daysInMonth() {
        if (this.__idate.iy && this.__idate.im) {
            return days_in_month(this.__idate.iy, this.__idate.im);
        }
        else {
            return null;
        }
    }
    get weeksFirstday() {
        if (this.__idate.iy && this.__idate.im) {
            const greg = islamic_to_greg({ iy: this.__idate.iy, im: this.__idate.im, id: 1 });
            return new Date(greg.gy, greg.gm - 1, greg.gd).getDay();
        }
        else {
            return null;
        }
    }
    get weekDay() { return this.__date ? this.__date.getDay() : null; }
    get ymd() { return this.__ymd(); }
    set ymd(ymd) {
        const greg = islamic_to_greg({ iy: ymd.year, im: ymd.month, id: ymd.date });
        this.use(new Date(greg.gy, greg.gm - 1, greg.gd, 0, 0, 0));
    }
    clone() {
        const clone = new NiIslamicDatetime();
        if (this.__date) {
            clone.use(new Date(this.__date));
        }
        return clone;
    }
}
/**
 * Jalali Implmentation of NiDate
 */
class NiJalaliDatetime extends NiDatetime {
    constructor(date) {
        super(date);
        this.__jdate = { jy: null, jm: null, jd: null };
        this.use(date);
    }
    use(date) {
        this.__jdate = date ? toJalaali(date) : { jy: null, jm: null, jd: null };
        return super.use(date);
    }
    get year() { return this.__jdate.jy; }
    get month() { return this.__jdate.jm; }
    get date() { return this.__jdate.jd; }
    get daysInMonth() {
        if (this.__jdate.jy && this.__jdate.jm) {
            return jalaaliMonthLength(this.__jdate.jy, this.__jdate.jm);
        }
        else {
            return null;
        }
    }
    get weeksFirstday() {
        if (this.__jdate.jy && this.__jdate.jm) {
            const greg = toGregorian(this.__jdate.jy, this.__jdate.jm, 1);
            return new Date(greg.gy, greg.gm - 1, greg.gd).getDay();
        }
        else {
            return null;
        }
    }
    get weekDay() { return this.__date ? this.__date.getDay() : null; }
    get ymd() { return this.__ymd(); }
    set ymd(ymd) {
        const greg = toGregorian(ymd.year, ymd.month, ymd.date);
        this.__date = new Date(greg.gy, greg.gm - 1, greg.gd, this.__date.getHours(), this.__date.getMinutes(), this.__date.getSeconds());
        this.use(this.__date);
    }
    clone() {
        const clone = new NiJalaliDatetime();
        if (this.__date) {
            clone.use(new Date(this.__date));
        }
        return clone;
    }
}
/**
 * Gregorian Implmentation of NiDate
 */
class NiGregorianDatetime extends NiDatetime {
    constructor(date) {
        super(date);
    }
    get year() { return this.__date.getFullYear(); }
    get month() { return this.__date.getMonth() + 1; }
    get date() { return this.__date.getDate(); }
    get daysInMonth() { return new Date(this.year, this.month, 0).getDate(); }
    get weeksFirstday() { return new Date(this.year, this.__date.getMonth(), 1).getDay(); }
    get weekDay() { return this.__date.getDay(); }
    get ymd() { return this.__ymd(); }
    set ymd(ymd) {
        this.__date = new Date(ymd.year, ymd.month - 1, ymd.date, this.__date.getHours(), this.__date.getMinutes(), this.__date.getSeconds());
        this.use(this.__date);
    }
    clone() {
        const clone = new NiGregorianDatetime();
        if (this.__date) {
            clone.use(new Date(this.__date));
        }
        return clone;
    }
}
const padNumber = (num, limit) => {
    return '0'.repeat(limit - num.toString().length) + num;
};
const formatDate = (calendar, locale, format) => {
    // ---------- formats ----------
    const f = {
        mediumDate: () => `${f.WWW()} ${f.DD()} ${f.MMM()}, ${f.YYYY()}`,
        mediumTime: () => `${f.hh()}:${f.mm()} ${f.a()}`,
        shortDate: () => `${f.YY()}/${f.M()}/${f.D()}`,
        shortTime: () => `${f.h()}:${f.m()} ${f.a()}`,
        longDate: () => `${f.WWWW()} ${f.DD()} ${f.MMMM()}, ${f.YYYY()}`,
        longTime: () => `${f.hh()}:${f.mm()}:${f.ss()} ${f.A()}`,
        medium: () => `${f.mediumDate()}, ${f.mediumTime()}`,
        short: () => `${f.shortDate()} ${f.shortTime()}`,
        long: () => `${f.longDate()} ${f.longTime()}`,
        iso: () => `${f.YYYY()}-${f.MM()}-${f.DD()}${calendar.__date.toISOString().substring(10)}`,
        YYYY: () => padNumber(calendar.year, 4),
        MMMM: () => locale.monthsName[calendar.month - 1],
        YY: () => padNumber(calendar.year, 4).substring(2),
        MMM: () => locale.monthsNameShort[calendar.month - 1],
        MM: () => padNumber(calendar.month, 2),
        M: () => calendar.month,
        DD: () => padNumber(calendar.date, 2),
        D: () => calendar.date,
        WWWW: () => locale.daysName[calendar.weekDay],
        WWW: () => locale.daysNameShort[calendar.weekDay],
        WW: () => locale.daysNameMini[calendar.weekDay],
        HH: () => padNumber(calendar.hours, 2),
        hh: () => padNumber(calendar.hours12, 2),
        H: () => calendar.hours,
        h: () => calendar.hours12,
        mm: () => padNumber(calendar.minutes, 2),
        m: () => calendar.minutes,
        ss: () => padNumber(calendar.seconds, 2),
        s: () => calendar.seconds,
        A: () => locale.AMPM[calendar.hours > 12 ? 1 : 0],
        a: () => locale.ampm[calendar.hours > 12 ? 1 : 0],
        z: () => calendar.__date.toString().substring(25, 33),
    };
    // one format may generate a value that can be misinterpreted by another format
    // use placeholers to hide each format output until concatenated at the end
    const placeholders = {};
    let counter = 0;
    // --- IMPORTANT NOTE ---
    // f.keys should be checked in order
    // so the longer format strings be evaulated first
    // ----------------------
    // .sort((a, b) => b.length - a.length)
    Object.keys(f).forEach(key => {
        while (format.indexOf(key) >= 0) {
            const placeholder = `$[[${counter++}]]`; // generate a placeholder
            placeholders[placeholder] = f[key](); // format and memorize for placeholder
            format = format.replace(key, placeholder); // replace key with placeholder
        }
    });
    // replace placeholders with values
    Object.keys(placeholders).forEach(pholder => format = format.replace(pholder, placeholders[pholder]));
    return format;
};
const ɵ0 = () => new NiJalaliDatetime(), ɵ1 = () => new NiJalaliDatetime(), ɵ2 = () => new NiJalaliDatetime(), ɵ3 = () => new NiIslamicDatetime(), ɵ4 = () => new NiGregorianDatetime();
/**
 * Default NiDate Locales
 */
const Locales = {
    fa_AF: {
        name: 'fa_AF',
        title: 'دری',
        new: ɵ0,
        week: '#',
        dir: 'rtl',
        firstday: 6,
        weekends: [5],
        daysName: ['یکشنبه', 'دوشنبه', 'سه شنبه', 'چهارشنبه', 'پنجشنبه', 'جمعه', 'شنبه'],
        daysNameShort: ['یک', 'دو', 'سه', 'چهار', 'پنج', 'جمعه', 'شنبه'],
        daysNameMini: ['ی', 'د', 'س', 'چ', 'پ', 'ج', 'ش'],
        monthsName: ['حمل', 'ثور', 'جوزا', 'سرطان', 'اسد', 'سنبله', 'میزان', 'عقرب', 'قوس', 'جدی', 'دلو', 'حوت'],
        monthsNameShort: ['حم', 'ثو', 'جو', 'سر', 'اس', 'سن', 'می', 'عق', 'قو', 'جد', 'دل', 'حو'],
        ampm: ['ق.ظ', 'ب.ظ'],
        AMPM: ['قبل از ظهر', 'بعد از ظهر'],
        today: 'امروز',
        clear: 'پاک'
    },
    ps_AF: {
        name: 'ps_AF',
        title: 'پښتو',
        new: ɵ1,
        week: '#',
        dir: 'rtl',
        firstday: 6,
        weekends: [5],
        daysName: ['یکښنبه', 'دوښنبه', 'سې ښنبه', 'چهارښنبه', 'پنجښنبه', 'جمعه', 'ښنبې'],
        daysNameShort: ['یک', 'دو', 'سې', 'چهار', 'پنج', 'جمعه', 'ښنبې'],
        daysNameMini: ['ی', 'د', 'س', 'چ', 'پ', 'ج', 'ښ'],
        monthsName: ['وری', 'غويی', 'غبرگولی', 'چنگاښ', 'زمری', 'وږی', 'تله', 'لړم', 'سلواغه', 'ليندۍ', 'مرغومی', 'کب'],
        monthsNameShort: ['وری', 'غويی', 'غبرگولی', 'چنگاښ', 'زمری', 'وږی', 'تله', 'لړم', 'سلواغه', 'ليندۍ', 'مرغومی', 'کب'],
        ampm: ['س', 'ښ'],
        AMPM: ['سهار', 'ماښام'],
        today: 'نن',
        clear: 'پاک'
    },
    fa_IR: {
        name: 'fa_IR',
        title: 'فارسی',
        new: ɵ2,
        week: '#',
        dir: 'rtl',
        firstday: 6,
        weekends: [5],
        daysName: ['یکشنبه', 'دوشنبه', 'سه شنبه', 'چهارشنبه', 'پنجشنبه', 'جمعه', 'شنبه'],
        daysNameShort: ['یک', 'دو', 'سه', 'چهار', 'پنج', 'جمعه', 'شنبه'],
        daysNameMini: ['ی', 'د', 'س', 'چ', 'پ', 'ج', 'ش'],
        monthsName: ['فروردین', 'اردیبهشت', 'خرداد', 'تیر', 'مرداد', 'شهریور',
            'مهر', 'آبان', 'آذر', 'دی', 'بهمن', 'اسفند'],
        monthsNameShort: ['فر', 'ار', 'خر', 'تی', 'مر', 'شه', 'مه', 'آب', 'آذ', 'دی', 'به', 'اس'],
        ampm: ['ق.ظ', 'ب.ظ'],
        AMPM: ['قبل از ظهر', 'بعد از ظهر'],
        today: 'امروز',
        clear: 'پاک'
    },
    ar_SA: {
        name: 'ar_SA',
        title: 'القمری',
        new: ɵ3,
        week: '#',
        dir: 'rtl',
        firstday: 0,
        weekends: [5, 6],
        daysName: ['الأحد', 'الإثنين', 'الثُلاثاء', 'الأربعاء', 'الخميس', 'الجُمْعَة', 'السبت'],
        daysNameShort: ['أحد', 'إثنين', 'ثُلاثاء', 'أربعاء', 'خميس', 'جُمْعَة', 'سبت'],
        daysNameMini: ['ح', 'ث', 'ثُ', 'ع', 'خ', 'جُ', 'س'],
        monthsName: ['محرم', 'صفر', 'ربيع الأول', 'ربيع الثاني', 'جمادى الأولى',
            'جمادى الآخرة', 'رجب', 'شعبان', 'رمضان', 'شوال', 'ذوالقعدة', 'ذوالحجة'],
        monthsNameShort: ['محرم', 'صفر', 'ربيع ١', 'ربيع ٢', 'جمادى ١',
            'جمادى ٢', 'رجب', 'شعبان', 'رمضان', 'شوال', 'ذو القعدة', 'ذو الحجة'],
        ampm: ['ق.ظ', 'ب.ظ'],
        AMPM: ['قبل الظهر', 'بعد الظهر'],
        today: 'اليوم',
        clear: 'نظيف'
    },
    en_US: {
        name: 'en_US',
        title: 'Gregorian',
        new: ɵ4,
        week: 'Wk',
        dir: 'ltr',
        firstday: 1,
        weekends: [6, 0],
        daysName: ['Sunday', 'Monday', 'Tuesday', 'Wedsday', 'Thursday', 'Friday', 'Saturday'],
        daysNameShort: ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
        daysNameMini: ['Su', 'Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa'],
        monthsName: ['January', 'February', 'March', 'April', 'May', 'June',
            'July', 'August', 'September', 'October', 'November', 'December'],
        monthsNameShort: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
        ampm: ['am', 'pm'],
        AMPM: ['AM', 'PM'],
        today: 'Today',
        clear: 'Clear'
    }
};
const toTimezone = (date, targetTimezoneUTCOffset) => {
    date = new Date(date.getTime());
    if (targetTimezoneUTCOffset) {
        // from local to utc
        date.setTime(date.getTime() + (date.getTimezoneOffset() * 60000));
        // from utc to target
        date.setTime(date.getTime() + (targetTimezoneUTCOffset * 60000));
    }
    return date;
};

class NiDatetimeModule {
}
NiDatetimeModule.decorators = [
    { type: NgModule, args: [{
                declarations: [],
                imports: [],
                exports: []
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { Hms, Locales, NiDatetime, NiDatetimeModule, NiGregorianDatetime, NiJalaliDatetime, Ymd, formatDate, padNumber, toTimezone };
//# sourceMappingURL=ni-datetime.js.map
